@@ -134,7 +134,6 @@ def get_nodes_by_name_and_namespace(
     namespace: str,
     options: ClientOptions = ClientOptions(),
 ) -> Optional[NodeV1]:
-
     node_id = NodeNamedID(name=name, namespace=namespace)
     return client.get(node_id, options=options)
 
@@ -203,8 +202,13 @@ def get_workspace_by_name_v1(
 ) -> Optional[Workspace]:
     if is_valid_uuid(name):
         url = f"{client.get_url(grai_type)}{name}"
-    url = f"{client.get_url(grai_type)}?name={name}"
+    elif len(name.split("/")) == 2:
+        # this is a ref string i.e. org-name/workspace-name
+        url = f"{client.get_url(grai_type)}?ref={name}"
+    else:
+        url = f"{client.get_url(grai_type)}?name={name}"
     resp = client.get(url, options=options).json()
+
     num_resp = len(resp)
     if num_resp == 0:
         return None
@@ -212,5 +216,8 @@ def get_workspace_by_name_v1(
         return Workspace(**resp[0])
     else:
         raise Exception(
-            f"Too many workspaces found matching the name {name}. This is a defensive error you should never see."
+            f"We were unable to identify a unique workspace matching `{name}` because more than one result was "
+            f"returned. This may be the result of belonging to multiple organizations with identical workspace "
+            f"names. You can narrow your query by instead providing a workspace ref composed of  "
+            "{org-name}/{workspace-name}.",
         )
